@@ -6,7 +6,7 @@
  * mpage:	a program to reduce pages of print so that several pages
  * 	  	of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -375,6 +375,8 @@ int last_encoding;	/* last encoding in character set */
 
 /* GPN. for coli */
 int Coli = 0;           /* value of 0 = don't mess, 1 = 4, 1 (outside pages)*/
+int use_utf8 = 0;       /* is input UTF-8 or not. */
+int check_utf8 = 1;     /* do we want to check for UTF-8 or not. */
 
 
 
@@ -382,7 +384,7 @@ void usage(int errcode)
 {
     fprintf(stderr, "\
  mpage - print multiple pages on postscript, version %s\n\n\
- mpage [-1248acEfHlkoOrRStvxX] [-b papersize] [-Btextboxmargin]\n\
+ mpage [-1248acEfHlkoOrRStvuVxX] [-b papersize] [-Btextboxmargin]\n\
        [-C [encodingfile]] [-da|p] [-D dateformat] [-F fontname]\n\
        [-h header] [-I indent] [-j pagespec] [-J startpageno] [-L lines]\n\
        [-msheetmargin] [-Mpagemargin] [-p[prprog]] [-P[printer]]\n\
@@ -400,6 +402,7 @@ void usage(int errcode)
  -F Text font to be used (%s)      -C Character encoding filename\n\
  -E Print every second and third page   -O Print every first and fourth page\n\
  -s Define tabstop width (%d)            -k kill on %%TRailer is PS file\n\
+ -V Show mpage version.\n               -u switch of utf-8 check\n\
  -b papersize (%s), use l or ? to get a list of sizes\n\
  -R Switch to across mode, with first page at lower left corner\n\
  -H Create page header for each page for text files\n\
@@ -422,7 +425,7 @@ void usage(int errcode)
     fontname, opt_tabstop, PAGE_DEF, printprog, printarg,
     opt_duplex ? "on" : "off"
     );
-    fprintf(stderr, "\n(c) 1993-2002 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
+    fprintf(stderr, "\n(c) 1993-2004 Marcel Mol, marcel@mesa.nl (MESA Consulting)\n");
 
     return;
 
