@@ -6,7 +6,7 @@
  * mpage:    a program to reduce pages of print so that several pages
  *           of output appear on one printed page.
  *
- * Copyright (c) 1994-1999 Marcel J.E. Mol, The Netherlands
+ * Copyright (c) 1994-2004 Marcel J.E. Mol, The Netherlands
  * Copyright (c) 1988 Mark P. Hahn, Herndon, Virginia
  *  
  *     Permission is granted to anyone to make or distribute verbatim
@@ -231,9 +231,9 @@ ps_title(name, outfd)
     fprintf(outfd, "/mp_pgc statusdict begin pagecount end def\n");
     fprintf(outfd, "statusdict begin /jobname (%s) def end\n", name);
     if (opt_duplex) {
-       fprintf(outfd, "%%BeginFeature: *Duplex DuplexNoTumble\n");
-       fprintf(outfd, "<< /Duplex true /Tumble false >> setpagedevice");
-       fprintf(outfd, "%%EndFeature");
+       fprintf(outfd, "%%%%BeginFeature: *Duplex DuplexNoTumble\n");
+       fprintf(outfd, "<< /Duplex true /Tumble false >> setpagedevice\n");
+       fprintf(outfd, "%%%%EndFeature\n");
        fprintf(outfd, "statusdict /setduplexmode known");
        fprintf(outfd, " { statusdict begin true setduplexmode end } if\n");
        if (opt_tumble) {
@@ -242,9 +242,15 @@ ps_title(name, outfd)
        }
     }
     else {
-       /* CAN WE DO THIS FOR PRINTERS THAT DO NOT NDERSTAND DUPLEX PRINTING??? */
+       /*
+        * CAN WE DO THIS FOR PRINTERS THAT DO NOT NDERSTAND DUPLEX PRINTING??? 
+        * It also seems to break for example the lp -o duplex command.
+        * So better switch this part of.
+        */
+#if 0
        fprintf(outfd, "statusdict /setduplexmode known");
        fprintf(outfd, " { statusdict begin false setduplexmode end } if\n");
+#endif
     }
 
     if (opt_encoding) {
@@ -329,6 +335,14 @@ ps_title(name, outfd)
     fprintf(outfd, "/han /Ryumin-Light.Hankaku findfont %d scalefont def\n", fsize - 1);
 #endif
 #endif
+#ifdef GOTHIC
+    fprintf(outfd, "/unijis /GothicBBB-Medium-UniJIS-UTF8-H findfont %d scalefont def\n", fsize - 1);
+#else
+    fprintf(outfd, "/unijis /Ryumin-Light-UniJIS-UTF8-H findfont %d scalefont def\n", fsize - 1);
+#endif
+    fprintf(outfd, "/uniks /Baekmuk-Batang-UniKS-UTF8-H findfont %d scalefont def\n", fsize - 1);
+    fprintf(outfd, "/unigb /BousungEG-Light-GB-UniGB-UTF8-H findfont %d scalefont def\n", fsize - 1);
+    fprintf(outfd, "/unicns /ShanHeiSun-Light-UniCNS-UTF8-H findfont %d scalefont def\n", fsize - 1);
 # ifdef DEBUG
     if (Debug_flag & DB_PSMPAGE)
         fprintf(outfd, "(\\t'a' length ) print mp_a_x ==\nflush\n");
